[tbb-commits] [torbutton] branch main updated: Bug 41460: Renamed the security level preferences

gitolite role git at cupani.torproject.org
Mon Nov 21 09:14:28 UTC 2022


This is an automated email from the git hooks/post-receive script.

pierov pushed a commit to branch main
in repository torbutton.

The following commit(s) were added to refs/heads/main by this push:
     new 60dc0713 Bug 41460: Renamed the security level preferences
60dc0713 is described below

commit 60dc0713f2bf6e4397c51e798643ca65784d234d
Author: Pier Angelo Vendrame <pierov at torproject.org>
AuthorDate: Thu Nov 17 18:33:36 2022 +0100

    Bug 41460: Renamed the security level preferences
    
    This commit should not be needed, very likely, because Android is now
    using Java code to plumb the value, but we add it to be on the safe
    side.
---
 chrome/content/preferences-mobile.js | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/chrome/content/preferences-mobile.js b/chrome/content/preferences-mobile.js
index 50cbfccd..b696ef17 100644
--- a/chrome/content/preferences-mobile.js
+++ b/chrome/content/preferences-mobile.js
@@ -39,12 +39,12 @@ function torbutton_set_slider(sliderValue) {
   torbutton_save_security_settings();
 }
 
 // Read prefs 'extensions.torbutton.security_slider' and
 // 'extensions.torbutton.security_custom', and initialize the UI.
 function torbutton_init_security_ui() {
   torbutton_set_slider(
     prefSettingToSliderPosition(
-      getIntPref("extensions.torbutton.security_slider")
+      getIntPref("browser.security_level.security_slider")
     )
   );
 }
@@ -52,8 +52,8 @@ function torbutton_init_security_ui() {
 // Write the two prefs from the current settings.
 function torbutton_save_security_settings() {
   setIntPref(
-    "extensions.torbutton.security_slider",
+    "browser.security_level.security_slider",
     sliderPositionToPrefSetting(state.slider)
   );
-  setBoolPref("extensions.torbutton.security_custom", state.custom);
+  setBoolPref("browser.security_level.security_custom", state.custom);
 }
@@ -39,12 +39,12 @@ function torbutton_set_slider(sliderValue) {
 }
 
-// Read prefs 'extensions.torbutton.security_slider' and
-// 'extensions.torbutton.security_custom', and initialize the UI.
+// Read prefs 'browser.security_level.security_slider' and
+// 'browser.security_level.security_custom', and initialize the UI.
 function torbutton_init_security_ui() {
   torbutton_set_slider(

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the tbb-commits mailing list